EnrichIntersect-package: EnrichIntersect: Enrichment Analysis and Intersecting Sankey...

EnrichIntersect-packageR Documentation

EnrichIntersect: Enrichment Analysis and Intersecting Sankey Diagram

Description

A flexible tool for enrichment analysis based on user-defined sets. It allows users to perform over-representation analysis of the custom sets among any specified ranked feature list, hence making enrichment analysis applicable to various types of data from different scientific fields. 'EnrichIntersect' also enables an interactive means to visualize identified associations based on, for example, the mix-lasso model (Zhao et al., 2022 \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.isci.2022.104767")}) or similar methods.

Author(s)

Maintainer: Zhi Zhao zhi.zhao@medisin.uio.no

Authors:

Other contributors:

See Also

Useful links:


EnrichIntersect documentation built on May 30, 2026, 9:11 a.m.