enrichment: Plot enrichment map

View source: R/enrichment.R

enrichmentR Documentation

Plot enrichment map

Description

Plot enrichment map through a vector or matrix of scores and a self-defined set that summarizes a few groups of the names of the vector or matrix.

Usage

enrichment(
  x,
  custom.set,
  alpha = 0,
  normalize = TRUE,
  permute.n = 100,
  padj.method = "none",
  pvalue.cutoff = 0.05,
  angle = 45,
  match.feature = c("rownames", "colnames"),
  ...
)

Arguments

x

a vector or matrix of scores to be enriched

custom.set

a self-defined set. The first column contains feature names, and the second column, preferably named "group", contains group names.

alpha

exponent weight of the score of ordered features.

normalize

logical value to determine if normalizing enrichment scores.

permute.n

number of custom-set permutations for significance testing.

padj.method

correction method passed to stats::p.adjust.

pvalue.cutoff

cutoff for both unadjusted and adjusted p-value.

angle

angle of rotating x-axis labels.

match.feature

one of "rownames" or "colnames". Default is "rownames", which keeps the original EnrichIntersect behavior.

...

other arguments

Value

A list including S, pvalue, and g.


EnrichIntersect documentation built on May 30, 2026, 9:11 a.m.