| EnrichIntersect-package | R Documentation |
A flexible tool for enrichment analysis based on user-defined sets. It allows users to perform over-representation analysis of the custom sets among any specified ranked feature list, hence making enrichment analysis applicable to various types of data from different scientific fields. 'EnrichIntersect' also enables an interactive means to visualize identified associations based on, for example, the mix-lasso model (Zhao et al., 2022 \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.isci.2022.104767")}) or similar methods.
Maintainer: Zhi Zhao zhi.zhao@medisin.uio.no
Authors:
Zhi Zhao zhi.zhao@medisin.uio.no
Manuela Zucknick manuela.zucknick@medisin.uio.no
Other contributors:
Tero Aittokallio t.a.aittokallio@medisin.uio.no [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.